@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2015 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -108,6 +108,14 @@ mpd_pure
 unsigned
 mpd_song_get_duration(const struct mpd_song *song);
 
+/**
+ * Returns the duration of this song in milliseconds.  0 means the
+ * duration is unknown.
+ */
+mpd_pure
+unsigned
+mpd_song_get_duration_ms(const struct mpd_song *song);
+
 /**
  * Returns the start of the virtual song within the physical file in
  * seconds.
